
# Slot: modified_by


agent that modified the element

URI: [linkml:modified_by](https://w3id.org/linkml/modified_by)


## Domain and Range

[Element](Element.md) &#8594;  <sub>0..1</sub> uriorcurie

## Parents


## Children


## Used by

 * class_definition
 * definition
 * slot_definition

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | oslc:modifiedBy |

